pub enum FilterCommand {
Show {
profile: Option<String>,
json: bool,
},
Explain {
profile: Option<String>,
client_ip: Option<IpAddr>,
identifiers: Vec<String>,
path: String,
account_id: String,
json: bool,
},
}Variants
Show
Print the resolved access policy for a profile.
Fields
Explain
Evaluate the policy against a hypothetical request.
This really runs your custom scripts and really queries the
inventory, exactly as a request would. It writes nothing, but like every
command but serve it needs a database that is migrated.
Fields