pub async fn explain(policy: &FilterPolicy, subject: &Subject) -> ExplanationExpand description
Evaluates the policy at the connection stage and both identifier sub-stages, keeping every trace.
pub async fn explain(policy: &FilterPolicy, subject: &Subject) -> ExplanationEvaluates the policy at the connection stage and both identifier sub-stages, keeping every trace.