Module authz

Module authz 

Structs

Authorization
An ACME authorization (RFC 8555 7.1.4). One authorization is created per order identifier when the order is created, starting in the pending state and carrying the challenges the client can satisfy to prove control of the identifier.
Challenge
An ACME challenge (RFC 8555 8): one proof the client may offer for its authorization’s identifier.